# Generated by Django 3.2.6 on 2021-08-18 08:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('emails', '0003_alter_usermodel_email'),
    ]

    operations = [
        migrations.DeleteModel(
            name='UserModel',
        ),
    ]
