# Generated by Django 3.2.6 on 2021-09-06 10:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('emails', '0008_remove_emailreminder_task'),
    ]

    operations = [
        migrations.CreateModel(
            name='Policy',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('user', models.CharField(max_length=20)),
                ('email', models.EmailField(max_length=254)),
                ('policy_name', models.CharField(max_length=30)),
                ('purchase_date', models.DateTimeField()),
                ('end_date', models.DateTimeField()),
                ('amount', models.IntegerField()),
            ],
        ),
    ]
