# Generated by Django 3.2.6 on 2021-08-30 05:49

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django_celery_beat', '0015_edit_solarschedule_events_choices'),
        ('emails', '0006_auto_20210819_0416'),
    ]

    operations = [
        migrations.AddField(
            model_name='emailreminder',
            name='task',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='django_celery_beat.periodictask'),
        ),
    ]
