# Generated by Django 3.2.6 on 2021-08-19 04:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('emails', '0005_emailreminder_notifications_pushreminder'),
    ]

    operations = [
        migrations.AlterField(
            model_name='emailreminder',
            name='occurrence',
            field=models.BooleanField(choices=[(True, 'single'), (False, 'recurring')], help_text='True for single'),
        ),
        migrations.AlterField(
            model_name='emailreminder',
            name='schedule',
            field=models.BooleanField(choices=[(True, 'before'), (False, 'after')]),
        ),
        migrations.AlterField(
            model_name='pushreminder',
            name='occurrence',
            field=models.BooleanField(choices=[(True, 'single'), (False, 'recurring')], help_text='True for single'),
        ),
        migrations.AlterField(
            model_name='pushreminder',
            name='schedule',
            field=models.BooleanField(choices=[(True, 'before'), (False, 'after')]),
        ),
    ]
