<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <title>Sending emails to user</title>
  </head>
  <body>
    Hello,{{user}}

    <p>{{body}}</p>

    <p>Thanks</p>
    <p>{{signature}}</p>
  </body>
</html>