# Generated by Django 3.2.6 on 2021-09-10 09:15

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('emails', '0016_delete_emailreminder'),
    ]

    operations = [
        migrations.CreateModel(
            name='Modules',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('modules', models.CharField(max_length=20)),
            ],
        ),
        migrations.CreateModel(
            name='EmailReminder',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('subject', models.CharField(max_length=20)),
                ('body', models.TextField(max_length=500)),
                ('signature', models.TextField(max_length=100)),
                ('occurrence', models.BooleanField(choices=[(True, 'single'), (False, 'recurring')], help_text='True for single')),
                ('schedule', models.BooleanField(choices=[(True, 'before'), (False, 'after')])),
                ('status', models.BooleanField(default=True)),
                ('schedule_days', models.IntegerField(blank=True, null=True)),
                ('schedule_hours', models.IntegerField(blank=True, null=True)),
                ('schedule_minutes', models.IntegerField(blank=True, null=True)),
                ('interval_days', models.IntegerField(blank=True, null=True)),
                ('interval_hours', models.IntegerField(blank=True, null=True)),
                ('interval_minutes', models.IntegerField(blank=True, null=True)),
                ('is_deleted', models.BooleanField(default=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('actions', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='emails.actions')),
                ('email_notification_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='emails.notifications')),
                ('modules', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='emails.modules')),
            ],
        ),
    ]
