# Generated by Django 3.2.6 on 2021-09-06 06:14

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('emails', '0007_emailreminder_task'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='emailreminder',
            name='task',
        ),
    ]
