# Generated by Django 3.2.5 on 2021-09-14 05:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('emails', '0019_list'),
    ]

    operations = [
        migrations.AddField(
            model_name='emailreminder',
            name='date_time',
            field=models.DateTimeField(null=True),
        ),
    ]
