# Generated by Django 3.2.6 on 2021-09-10 12:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('emails', '0018_delete_notify'),
    ]

    operations = [
        migrations.CreateModel(
            name='List',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('list', models.CharField(max_length=20)),
            ],
        ),
    ]
