# Generated by Django 3.2.6 on 2021-08-17 13:47

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='EmailModel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('creator_name', models.CharField(max_length=20)),
                ('email_host', models.CharField(max_length=30)),
                ('email_use_tls', models.BooleanField(help_text='True for Gmail')),
                ('email_use_ssl', models.BooleanField(help_text='False for Gmail')),
                ('email_port', models.IntegerField()),
                ('email_host_user', models.EmailField(max_length=254)),
                ('email_host_password', models.CharField(max_length=50)),
                ('data_created', models.DateField(auto_now_add=True)),
                ('last_modified', models.DateField(auto_now=True)),
            ],
        ),
    ]
