# Generated by Django 3.2.6 on 2021-08-18 12:47

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('emails', '0004_delete_usermodel'),
    ]

    operations = [
        migrations.CreateModel(
            name='Notifications',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('notification_type', models.CharField(max_length=30)),
            ],
        ),
        migrations.CreateModel(
            name='PushReminder',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=20)),
                ('message', models.TextField(max_length=100)),
                ('image', models.ImageField(upload_to='reminder')),
                ('url', models.URLField()),
                ('occurrence', models.BooleanField(choices=[('Single', True), ('Recurring', False)], help_text='True for single')),
                ('schedule', models.BooleanField(choices=[('Before', True), ('After', False)])),
                ('status', models.BooleanField(default=True)),
                ('interval_period', models.DateTimeField()),
                ('is_deleted', models.BooleanField(default=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='EmailReminder',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('subject', models.CharField(max_length=20)),
                ('body', models.TextField(max_length=500)),
                ('signature', models.TextField(max_length=100)),
                ('occurrence', models.BooleanField(choices=[('Single', True), ('Recurring', False)], help_text='True for single')),
                ('schedule', models.BooleanField(choices=[('Before', True), ('After', False)])),
                ('status', models.BooleanField(default=True)),
                ('interval_period', models.DateTimeField()),
                ('is_deleted', models.BooleanField(default=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('email_notification_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='emails.notifications')),
            ],
        ),
    ]
