# Generated by Django 3.2.6 on 2021-08-18 07:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('emails', '0002_usermodel'),
    ]

    operations = [
        migrations.AlterField(
            model_name='usermodel',
            name='email',
            field=models.EmailField(max_length=254, unique=True),
        ),
    ]
